#===============================================================================
#. Universidade Estadual de Santa Cruz
#. Disciplina: CET076 - Metodologia e Estatstica Experimental
# 29/11/2022 16:46:37
#===============================================================================
# Docente: Jos C. Faria
# Discentes: Alane, Nikary, Silvana 
# Script Delineamento Inteiramente ao Acaso - DIC
# 
# O experimento foi conduzido no DIC, com quatro repeties,
# para avaliar a altura de plantas da espcie florestal accia (A. holocericeae)
# submetidas a diferentes substratos para formao de mudas.
# Os resultados avaliados sero apresentados em altura de planta (cm).
#===============================================================================

#. Pacotes necessrios
#TukeyC
#ScottKnott
#gplots

#. Carregando dados
dad <- read.table('dic.txt',
                  head=T,
                  dec=',',
                  stringsAsFactors=T
                  )
str(dad)
head(dad)
summary(dad)
dad

#. Verificaes importantes para ANOVA e TCMM
is.factor(dad$tra)
is.numeric(dad$alt)


#. Anlises grficas
#... Diagrama de caixa
plot(alt ~ tra,  
     data=dad,
     ylab='Altura, cm',
     xlab='Tratamentos')

# Carregando o pacote gplots
library(gplots)

#... plotmeans
plotmeans(alt ~ tra,
          #main='Tratamentos',
          data=dad,
          mean.labels=TRUE,
          digits=2,
          connect=FALSE,
          ylab='Altura, cm',
          xlab='Tratamentos',
          pch=' ')


#. ANOVA e cv
av <- aov(alt ~ tra,
          data=dad)

summary(av)

# Coeficiente de Variao
library(TukeyC)
cv(av)

# O script comentado abaixo  opcional
# # Grfico das hipteses: 5 e  o 18 so os graus de liberdade da varivel 
#   tra e residual respectivamente
# # F tabelado
# Ftab <- qf(5 / 100,
#            5,
#            18,
#            lower.tail=FALSE)
# Ftab
#
# curve(expr=df(x,
#               5,
#               18),
#       main="Distribuio F de Fisher (df=5, 18)",
#       xlab="Valor F",
#       ylab="Densidade Probabilstica (df)",
#       xlim=c(0,10))
#
# abline(v=Ftab,
#        col="red")
#
# abline(h=0,
#        lty=2)
#
# xf=seq(Ftab,
#        10,
#        0.01)
#
# ydf=df(xf,
#        5,
#        18)
#
# polygon(c(Ftab,
#           xf),
#         c(0,
#           ydf),
#         col="red")
#
# text(locator(1),          # D um click no grfico na posio que quer o texto!
#      paste("pf(x) =",
#            round(pf(Ftab,
#                     5,
#                     18,
#                     lower.tail=F),
#                  4)),
#      cex=0.8,
#      col="red")


#. Teste de Tuckey
# Default sig.level = 5/100
tk <- TukeyC(av)  
summary(tk)

plot(tk,
     xlab='Tratamentos',
     ylab='Altura, cm',
     col= 'blue',
     col.lab= 'red',
     disp='mm')

# sig.level = 6.5/100
tk2 <- TukeyC(av, 
              sig.level=6.5/100)  

summary(tk2)

plot(tk2,
     xlab='Tratamentos',
     ylab='Altura, cm',
     col= 'blue',
     col.lab= 'red',
     disp='mm')


#. Teste de Scott Knott
library(ScottKnott)

# Default sig.level = 5/100
sk <- SK(av)  
summary(sk)

plot(sk,
     xlab='Tratamentos',
     ylab='Altura, cm',
     col= 'blue',
     col.lab= 'red',
     disp='mm')

# sig.level = 6.5/100
sk2 <- SK(av,
          sig.level=6.5/100)  
summary(sk2)

plot(sk2,
     xlab='Tratamentos',
     ylab='Altura, cm',
     col= 'blue',
     col.lab= 'red',
     disp='mm')

#. Contrastes ortogonais
                                               # T1  T2  T3  T4  T5  T6
cmat <- rbind('(T1, T6, T3) vs (T2, T4, T5)' = c( 1, -1,  1, -1, -1,  1),
              'T3 vs (T1, T6)'               = c(-1,  0,  2,  0,  0, -1),
              'T6 vs T1'                     = c( 1,  0,  0,  0,  0, -1),
              'T4 vs (T5, T2)'               = c( 0, -1,  0,  2, -1,  0),
              'T5 vs T2'                     = c( 0, -1,  0,  0,  1,  0))

library(gmodels)
av_c <- aov(alt ~ tra,
            data=dad,
            contrasts=list(tra=make.contrasts(cmat)))  # Usa a funo make.contrasts do pacote gmodels

effects(av_c)[2:6]

#.. Decomposio da SQTra em contrastes ortogonais
summary(av_c,
        split=list(tra=list('(T1, T6, T3) vs. (T2, T4, T5)' = 1,
                            'T3 vs. (T1, T6)'               = 2,
                            'T1 vs. T6'                     = 3,
                            'T4 vs. (T5, T2)'               = 4,
                            'T5 vs. T2'                     = 5)))

#.. Mudando apenas os labels dos contrastes
summary(av_c,
        split=list(tra=list('C1' = 1,
                            'C2' = 2,
                            'C3' = 3,
                            'C4' = 4,
                            'C5' = 5)))
